Crypto-NanoRPC version 0.9.1
============================
INSTALLATION
To install this module type the following:
perl Makefile.PL
make
make test
make install
DEPENDENCIES
This module requires these other modules and libraries:
JSON
LWP::UserAgent
HTTP::Request
COPYRIGHT AND LICENCE
Copyright (C) 2020 by Ruben de Groot
This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.18.1 or,
at your option, any later version of Perl 5 you may have available.